@@ -1,5 +1,5 @@
 package TreePath::Role::Graph;
-$TreePath::Role::Graph::VERSION = '0.05';
+$TreePath::Role::Graph::VERSION = '0.07';
 use Moose::Role;
 use MooseX::Types::Path::Class;
 use GraphViz2;
@@ -23,9 +23,8 @@ sub graph {
 
     my $g = GraphViz2->new();
     foreach my $id ( sort { $a cmp $b } keys %{$self->tree}) {
-
         my $node   = $self->tree->{$id};
-        my $parent = $node->{parent};
+        my $parent = $node->{$self->_get_key_name('parent', $node)};
 
         my @keys_children = sort grep {/^children.*/} keys %$node;
 
@@ -39,22 +38,21 @@ sub graph {
         }
 
         my $label = "{ $label_keys_children "
-            . $node->{$self->_search_field}
-            . " (". $node->{$self->_source_field} . '_' . $node->{id}
+            . $node->{$self->_get_key_name('search', $node)}
+            . " (". $node->{$self->_get_key_name('source', $node)} . '_' . $node->{$self->_get_key_name('primary', $node)}
             .")}";
 
         my $fg_color = 'black';
-        if ( defined $self->colors && defined $self->colors->{$node->{$self->_source_field}}) {
-            $fg_color = $self->colors->{$node->{$self->_source_field}}->{fg};
+        if ( defined $self->colors && defined $self->colors->{$node->{$self->_get_key_name('source', $node)}}) {
+            $fg_color = $self->colors->{$node->{$self->_get_key_name('source', $node)}}->{fg};
         }
-        my $key_obj = $self->_key_obj($node);
+        my $key_obj = $self->_obj_key($node);
         $g->add_node( name => $key_obj, label => $label, shape => 'record', color => $fg_color);
 
-        if ( $node->{parent} ){
+        if ( $parent ){
             my $key_children = $self->_key_children($node, $parent);
-            my $key_parent = $self->_key_obj($parent);
+            my $key_parent = $self->_obj_key($parent);
             $g->add_edge( from => $key_obj, to => "$key_parent:_${key_children}_"  );
-
             }
     }
 
@@ -70,7 +68,7 @@ TreePath::Role::Graph - Role to visualize TreePath Graph
 
 =head1 VERSION
 
-version 0.05
+version 0.07
 
 =head1 SYNOPSIS
 
